lxm3.xm\_cluster.JobRequirements
================================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: JobRequirements

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~JobRequirements.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~JobRequirements.task_requirements
      ~JobRequirements.accelerator
      ~JobRequirements.location
   
   